@@ -10,6 +10,9 @@ import pandas as pd
 import numpy as np
 from collections import Counter
 import matplotlib.pyplot as plt
+import datetime
+
+from torch import swapdims 
 plt.rcParams.update({'font.family': 'STIXGeneral', 'mathtext.fontset': 'stix'})
 
 ###########################################################################################
@@ -128,7 +131,7 @@ def load_supplier():
              79,  80,  81,  82,  83,  84,  85,  86,  87,  88,  89,  90,  91,
              92,  93,  94,  95,  96,  97,  98,  99, 100]
     feature_names = ['Warranty Terms', 'Payment Terms', 'Technical Support',
-       'Sustainability Efforts', 'Financial Stability', 'Unit Cost',
+       'Sustainability Efforts', 'Finp.nancial Stability', 'Unit Cost',
        'Lead Time (Days)', 'On Time Delivery']
     supplier = pd.DataFrame(data=data,index = index,columns = feature_names)
     return supplier
@@ -139,77 +142,77 @@ def load_supplier():
 def load_roller20():
     data = np.array([['10 Inversion Roller Coaster', 'Chimelong Paradise', 'Panyu',
         'Guangzhou, Guangdong', 'China', 'Asia', 'Steel', 'Sit Down',
-        'Operating', 2006, 98.4, 45.0, 2788.8, 'YES', 10, nan,
-        datetime.time(1, 32), nan, nan],
+        'Operating', 2006, 98.4, 45.0, 2788.8, 'YES', 10, np.nan,
+        datetime.time(1, 32), np.nan, np.nan],
        ['Abismo', 'Parque de Atracciones de Madrid', 'Madrid', 'Madrid',
         'Spain', 'Europe', 'Steel', 'Sit Down', 'Operating', 2006, 151.6,
-        65.2, 1476.4, 'YES', 2, nan, datetime.time(1, 0), 4, nan],
+        65.2, 1476.4, 'YES', 2, np.nan, datetime.time(1, 0), 4, np.nan],
        ['Adrenaline Peak', 'Oaks Amusement Park', 'Portland', 'Oregon',
         'United States', 'North America', 'Steel', 'Sit Down',
-        'Operating ', 2018, 72, 45.0, 1050.0, 'YES', 3, nan, nan, nan,
+        'Operating ', 2018, 72, 45.0, 1050.0, 'YES', 3, np.nan, np.nan, np.nan,
         97.0],
        ['Afterburn', 'Carowinds', 'Charlotte', 'North Carolina',
         'United States', 'North America', 'Steel', 'Inverted',
-        'Operating', 1999, 113, 62.0, 2956.0, 'YES', 6, nan,
-        datetime.time(2, 47), nan, nan],
+        'Operating', 1999, 113, 62.0, 2956.0, 'YES', 6, np.nan,
+        datetime.time(2, 47), np.nan, np.nan],
        ['Alpengeist', 'Busch Gardens Williamsburg', 'Williamsburg',
         'Virginia', 'United States', 'North America', 'Steel',
         'Inverted', 'Operating', 1997, 195, 67.0, 3828.0, 'YES', 6, 170,
-        datetime.time(3, 10), 3.7, nan],
+        datetime.time(3, 10), 3.7, np.nan],
        ['Alpina Blitz', 'Nigloland', 'Dolancourt', 'Champagne-Ardenne',
         'France', 'Europe', 'Steel', 'Sit Down', 'Operating', 2014,
-        108.3, 51.6, 2358.9, 'NO', 0, nan, nan, 4.3, nan],
+        108.3, 51.6, 2358.9, 'NO', 0, np.nan, np.nan, 4.3, np.nan],
        ['Altair', 'Cinecittà World', 'Rome', 'Rome', 'Italy', 'Europe',
         'Steel', 'Sit Down', 'Operating', 2014, 108.3, 52.8, 2879.8,
-        'YES', 10, nan, nan, nan, nan],
+        'YES', 10, np.nan, np.nan, np.nan, np.nan],
        ['American Eagle', 'Six Flags Great America', 'Gurnee',
         'Illinois', 'United States', 'North America', 'Wood', 'Sit Down',
         'Operating', 1981, 127, 66.0, 4650.0, 'NO', 0, 147,
-        datetime.time(2, 23), nan, 55.0],
+        datetime.time(2, 23), np.nan, 55.0],
        ['Anaconda', 'Walygator Parc', 'Maizieres-les-Metz ', 'Lorraine',
         'France', 'Europe', 'Wood', 'Sit Down', 'Operating', 1989, 118.1,
-        55.9, 3937.0, 'NO', 0, 40, datetime.time(2, 10), nan, nan],
+        55.9, 3937.0, 'NO', 0, 40, datetime.time(2, 10), np.nan, np.nan],
        ['Apocalypse', 'Six Flags America', 'Upper Marlboro', 'Maryland',
         'United States', 'North America', 'Steel', 'Stand Up',
         'Operating', 2012, 100, 55.0, 2900.0, 'YES', 2, 90,
-        datetime.time(2, 0), nan, nan],
+        datetime.time(2, 0), np.nan, np.nan],
        ['Apocalypse the Ride', 'Six Flags Magic Mountain', 'Valencia',
         'California', 'United States', 'North America', 'Wood',
         'Sit Down', 'Operating', 2009, 95, 50.1, 2877.0, 'NO', 0, 87.3,
-        datetime.time(3, 0), nan, nan],
+        datetime.time(3, 0), np.nan, np.nan],
        ["Apollo's Chariot", 'Busch Gardens Williamsburg', 'Williamsburg',
         'Virginia', 'United States', 'North America', 'Steel',
         'Sit Down', 'Operating', 1999, 170, 73.0, 4882.0, 'NO', 0, 210,
         datetime.time(2, 15), 4.1, 65.0],
        ['Atlantica SuperSplash', 'Europa Park', 'Rust ',
         'Baden Wuerttemberg', 'Germany', 'Europe', 'Steel', 'Sit Down',
-        'Operating', 2005, 98.4, 49.7, 1279.5, 'NO', 0, nan,
-        datetime.time(3, 20), nan, nan],
+        'Operating', 2005, 98.4, 49.7, 1279.5, 'NO', 0, np.nan,
+        datetime.time(3, 20), np.nan, np.nan],
        ['Backlot Stunt Coaster', 'Kings Island', 'Kings Mills', 'Ohio',
         'United States', 'North America', 'Steel', 'Sit Down',
         'Operating', 2005, 45.2, 40.0, 1960.0, 'NO', 0, 31.2,
-        datetime.time(1, 4), nan, nan],
+        datetime.time(1, 4), np.nan, np.nan],
        ['Balder', 'Liseberg', 'Gothenburg', 'Vastra Gotaland', 'Sweden',
         'Europe', 'Wood', 'Sit Down', 'Operating', 2003, 118.1, 55.9,
-        3510.5, 'NO', 0, nan, datetime.time(2, 8), nan, 70.0],
+        3510.5, 'NO', 0, np.nan, datetime.time(2, 8), np.nan, 70.0],
        ['Bandit', 'Movie Park Germany', 'Bottrop ',
         'North Rhine-Westphali', 'Germany', 'Europe', 'Wood', 'Sit Down',
         'Operating', 1999, 91.2, 49.7, 3605.7, 'NO', 0, 81.7,
-        datetime.time(1, 30), nan, nan],
+        datetime.time(1, 30), np.nan, np.nan],
        ['Banshee', 'Kings Island', 'Mason', 'Ohio', 'United States',
         'North America', 'Steel', 'Inverted', 'Operating', 2014, 167,
-        68.0, 4124.0, 'YES', 7, 150, datetime.time(2, 40), nan, nan],
+        68.0, 4124.0, 'YES', 7, 150, datetime.time(2, 40), np.nan, np.nan],
        ['Bat', 'Kings Island', 'Kings Mills', 'Ohio', 'United States',
         'North America', 'Steel', 'Suspended', 'Operating', 1993, 78,
-        51.0, 2352.0, 'NO', 0, nan, datetime.time(1, 52), nan, nan],
+        51.0, 2352.0, 'NO', 0, np.nan, datetime.time(1, 52), np.nan, np.nan],
        ['Batman - The Dark Knight', 'Six Flags New England', 'Agawam',
         'Massachusetts', 'United States', 'North America', 'Steel',
         'Sit Down', 'Operating ', 2002, 117.8, 55.0, 2600.0, 'YES', 5,
-        nan, datetime.time(2, 20), nan, nan],
+        np.nan, datetime.time(2, 20), np.nan, np.nan],
        ['Batman The Ride', 'Six Flags Great America', 'Gurnee',
         'Illinois', 'United States', 'North America', 'Steel',
-        'Inverted', 'Operating', 1992, 100, 50.0, 2700.0, 'YES', 5, nan,
-        datetime.time(2, 0), nan, nan]]
+        'Inverted', 'Operating', 1992, 100, 50.0, 2700.0, 'YES', 5, np.nan,
+        datetime.time(2, 0), np.nan, np.nan]])
     index = range(len(data))
     feature_names = ['Name', 'Park', 'City/Region', 'City/State/Region', 'Country/Region',
        'Geographic Region', 'Construction', 'Type', 'Status',
@@ -219,58 +222,155 @@ def load_roller20():
     roller = pd.DataFrame(data=data,index = index,columns = feature_names)
     return roller
 
-    
+
+####***************************     1.3 Aircraft       ****************************###
+
+def load_aircraft():
+    data = np.array([[2.0e+00, 1.5e+03, 2.0e+04, 5.5e+06, 5.0e-01, 1.0e+00],
+       [2.5e+00, 2.7e+03, 1.8e+04, 6.5e+06, 3.0e-01, 5.0e-01],
+       [1.8e+00, 2.0e+03, 2.1e+04, 4.5e+06, 7.0e-01, 7.0e-01],
+       [2.2e+00, 1.8e+03, 2.0e+04, 5.0e+06, 5.0e-01, 5.0e-01]])
+    index = list('ABCD')
+    feature_names = ['最大速度(马赫)', '飞行范围(km)', '最大负载(磅)', '费用(美元)', '可靠性', '灵敏性']
+    aircraft = pd.DataFrame(data=data,index = index,columns = feature_names)
+    return aircraft
 
 
+####***************************     1.4 Hospital       ****************************###
+
+def load_hospital():
+    data = np.array([[100,90,100,84,90,100,100,100,100],
+    [100,100,78.6,100,90,100,100,100,100],
+    [75,100,85.7,100,90,100,100,100,100],
+    [100,100,78.6,100,90,100,94.4,100,100],
+    [100,90,100,100,100,90,100,100,80],
+    [100,100,100,100,90,100,100,85.7,100],
+    [100 ,100 ,78.6,100 ,90 , 100, 55.6,    100, 100],
+    [87.5,100,85.7, 100 ,100 ,100, 100 ,100 ,100],
+    [100 ,100, 92.9 , 100 ,80 , 100 ,100 ,100 ,100],
+    [100,90 ,100 ,100,100, 100, 100, 100, 100],
+    [100,100 ,92.9 , 100, 90 , 100, 100 ,100 ,100]])
+
+    index = list('ABCDEFGHIJK')
+    columns = range(1,10)
+    hospital= pd.DataFrame(data=data,index=index,columns=columns)
+    return hospital
+
+###########################################################################################
+###############################     2 Optimization         ###############################
+###########################################################################################
+
+####***************************     2.1 Portfolio       ****************************###
+
+def load_portfolio():
+    data = np.array([[28,2.5,1,103],[21,1.5,2,198],[23,5.5,4.5,52],[25,2.6,6.5,40]])
+    index = ['s'+str(i) for i in range(1,5)]
+    columns = ['s','r(\%)','q(\%)','p(\%)','u(RMB)']
+    portfolio= pd.DataFrame(data=data,index=index,columns=columns)
+    return portfolio
+
+####***************************     2.2 Ambulance       ****************************###
+
+def load_ambulance():
+    data = np.array([[1,1,0,0,0,0],
+                    [1,1,1,0,0,0],
+                    [0,0,1,0,1,1],
+                    [0,0,1,1,0,0],
+                    [0,0,0,1,1,1],
+                    [0,0,1,0,1,1]])
+    index = range(6)
+    columns = range(6)
+    ambulance = pd.DataFrame(data=data,index=index,columns=columns)
+    return ambulance
+
+####***************************     2.3 Ambulance       ****************************###
+def load_oil():
+    data = np.array([[110, 120, 130, 110, 115,-150],[8.8,6.1,2.0,4.2,5.0,-6]])
+    index = ['价格','硬度']
+    columns = ['VEG1','VEG2','OIL1','OIL2','OIL3']
+    oil = pd.DataFrame(data=data,index=index,columns=columns).T
+    return oil
+
+####***************************     2.4 Factory(clothes) ****************************###
+def load_factory_clothes():
+    data = np.array([[[5000, 280, 400, 5, 3.0, 300],
+       [2000, 30, 40, 1, 0.5, 300],
+       [2000, 200, 300, 4, 2.0, 300]])
+    index = list('ABC')
+    columns = ['服装种类', '设备租金(元)', '材料成本(元/件)', '销售价格(元/件)', '人工工时(小时/件)', '设备工时(小时/件)',
+       '设备可用工时']
+    factory_clothes = pd.DataFrame(data=data,index=index,columns=columns)
+    return factory_clothes
+
+####***************************     2.3 Swim           ****************************###
+def swim():
+    data = np.array([[ 56, 74, 61, 63],
+       [63, 69, 65, 71],
+       [57, 77, 63, 67]
+       [ 55, 76, 62, 62]])
+    index = ['A','B', 'C','D']
+    columns = ['泳姿1', '泳姿2', '泳姿3', '泳姿4']
+    swim = pd.DataFrame(data=data,index=index,columns=columns)
+    return swim
 
 
+###########################################################################################
+###############################     3 Change        ###############################
+###########################################################################################
 
+####***************************     3.1 Shanghai Confirms(from March 1)       ****************************###
 
+def shanghaicases():
+    data = np.array([[1.0000e+00, 1.0000e+00,        np.nan,        np.nan, 1.0000e+00],
+       [3.0000e+00, 5.0000e+00,        np.nan,        np.nan, 5.0000e+00],
+       [2.0000e+00, 1.4000e+01,        np.nan,        np.nan, 1.4000e+01],
+       [3.0000e+00, 1.6000e+01,        np.nan,        np.nan, 1.5000e+01],
+       [0.0000e+00, 2.8000e+01,        np.nan,        np.nan, 2.8000e+01],
+       [3.0000e+00, 4.5000e+01,        np.nan,        np.nan, 4.4000e+01],
+       [4.0000e+00, 5.1000e+01,        np.nan,        np.nan, 5.1000e+01],
+       [3.0000e+00, 6.2000e+01,        np.nan,        np.nan, 6.1000e+01],
+       [4.0000e+00, 7.6000e+01,        np.nan,        np.nan, 6.4000e+01],
+       [1.1000e+01, 6.4000e+01,        np.nan, 0.0000e+00, 6.1000e+01],
+       [5.0000e+00, 7.8000e+01,        np.nan, 4.0000e+00, 5.7000e+01],
+       [1.0000e+00, 6.4000e+01,        np.nan, 1.0000e+00, 6.0000e+01],
+       [4.1000e+01, 1.2800e+02, 2.0000e+00, 3.2000e+01, 9.0000e+01],
+       [9.0000e+00, 1.3000e+02,        np.nan, 5.0000e+00, 1.0200e+02],
+       [5.0000e+00, 1.9700e+02,        np.nan, 4.0000e+00, 1.3500e+02],
+       [8.0000e+00, 1.5000e+02, 1.0000e+00, 2.0000e+00, 6.9000e+01],
+       [5.7000e+01, 2.0300e+02,        np.nan, 2.0000e+00, 1.0300e+02],
+       [8.0000e+00, 3.6600e+02,        np.nan, 4.0000e+00, 1.7800e+02],
+       [1.7000e+01, 4.9200e+02, 6.0000e+00, 9.0000e+00, 2.3200e+02],
+       [2.4000e+01, 7.3400e+02,        np.nan, 2.2000e+01, 6.5200e+02],
+       [3.1000e+01, 8.6500e+02,        np.nan, 3.0000e+01, 7.4900e+02],
+       [4.0000e+00, 9.7700e+02,        np.nan, 3.0000e+00, 8.8600e+02],
+       [4.0000e+00, 9.7900e+02,        np.nan, 4.0000e+00, 8.7800e+02],
+       [2.9000e+01, 1.5800e+03,        np.nan, 1.2000e+01, 1.4550e+03],
+       [3.8000e+01, 2.2310e+03, 5.0000e+00, 3.0000e+00, 1.7730e+03],
+       [4.5000e+01, 2.6310e+03,        np.nan, 2.7000e+01, 2.3630e+03],
+       [5.0000e+01, 3.4500e+03,        np.nan, 1.7000e+01, 2.8330e+03],
+       [9.6000e+01, 4.3810e+03, 2.1000e+01, 7.0000e+00, 3.8240e+03],
+       [3.2600e+02, 5.6560e+03, 1.8000e+01, 1.7000e+01, 5.1310e+03],
+       [3.5500e+02, 5.2980e+03, 1.6000e+01, 1.0000e+01, 4.4770e+03],
+       [3.5800e+02, 4.1440e+03, 2.0000e+01, 8.0000e+00, 3.7100e+03],
+       [2.6000e+02, 6.0510e+03, 8.0000e+00, 4.0200e+02, 5.4020e+03],
+       [4.3800e+02, 7.7880e+03, 7.3000e+01, 1.6000e+01, 6.7730e+03],
+       [4.2500e+02, 8.5810e+03, 7.1000e+01, 7.0000e+00, 7.9200e+03],
+       [2.6800e+02, 1.3086e+04, 4.0000e+00, 1.4000e+01, 1.2592e+04],
+       [3.1100e+02, 1.6766e+04, 4.0000e+01, 4.0000e+00, 1.6256e+04],
+       [3.2200e+02, 1.9660e+04, 1.5000e+01, 1.2000e+01, 1.9027e+04],
+       [8.2400e+02, 2.0398e+04, 3.2300e+02, 1.2100e+02, 1.9798e+04],
+       [1.0150e+03, 2.2609e+04, 4.2000e+02, 3.0100e+02, 2.1853e+04],
+       [1.0060e+03, 2.3937e+04, 1.9100e+02, 2.2800e+02, 2.3412e+04],
+       [9.1400e+02, 2.5173e+04, 4.7000e+01, 5.6400e+02, 2.4230e+04],
+       [9.9400e+02, 2.2348e+04, 2.7300e+02, 4.3900e+02, 2.1844e+04]])
+    index = range(len(data))
+    columns = ['新增确诊', '新增无症状', '无症状者转归', '隔离管控确诊', '隔离管控无症状']
+    shanghai = pd.DataFrame(data=data,index=index,columns=columns)
+    return shanghai
 
-
-
-
-
-
-
-
-def Normalize_Weights(weights_array,norm_type = 'divide_by_sum'):
-    """Normalizes a provided weight array so that the sum equals 1
-
-    Parameters
-    ----------
-    weights_array : a numpy array containing the raw weights
-    
-    norm_type : a string specifying the type of normalization to perform
-        - 'divide_by_max' divides all values by the maximum value
-        - 'divide_by_sum' divides all values by the sum of the values
-
-    Yields
-    ------
-    temp_weights_array: a copy of the passed weights array with the normalizations performed
-
-    Examples
-    --------
-    >>> import numpy as np
-    >>> import mcdm_functions as mcfunc
-    >>> criteria_weights = np.array([2,4,6,7,9])
-    >>> temp = mcfunc.Normalize_Weights(criteria_weights,'divide_by_max')
-    >>> print(temp)
-    
-        [ 0.22222222  0.44444444  0.66666667  0.77777778  1.        ]
-    """   
-    
-    temp_weights_array = weights_array.copy()
-    
-    if norm_type is 'divide_by_max':
-        temp_weights_array = temp_weights_array/temp_weights_array.max()
-
-    elif norm_type is 'divide_by_sum':
-        temp_weights_array = temp_weights_array/temp_weights_array.sum()
-        
-    else:
-        print('You did not enter a valid type, so no changes were made')
-    
-    return temp_weights_array
-
-
+####***************************     3.2 Population      ****************************###
+def population():
+    df = pd.DataFrame()
+    df["年份"] = [i for i in  range(1790,2010,10)]
+    df["人口"] = [3.9,5.3,7.2,9.6,12.9,17.1,23.2,31.4,38.6,50.2,62.9,76,92,106.5,123.2,131.7,150.7,179.3,204,226.5,251.4,281.4]
+    return df.T
